package rition.backend.api.v1.panel;

import org.springframework.web.bind.annotation.*;
import rition.backend.api.v1.dto.request.AlertRuleAddRequest;
import rition.backend.api.v1.dto.response.Response;
import rition.backend.api.v1.dto.response.RuleResponse;
import rition.common.data.dto.service.panel.AlertRuleAddDto;
import rition.common.data.entity.RuleEntity;
import rition.service.panel.AlertRuleService;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/panel/rules")
public class AlertRuleController {
    private final AlertRuleService alertRuleService;

    public AlertRuleController(AlertRuleService alertRuleService) {
        this.alertRuleService = alertRuleService;
    }

    @GetMapping("/list")
    public Response<List<RuleResponse>> getAlertRuleList() {
        List<RuleEntity> ruleEntityList = alertRuleService.getRule();
        List<RuleResponse> ruleResponseList = new ArrayList<>(ruleEntityList.size());
        for (RuleEntity ruleEntity : ruleEntityList) {
            RuleResponse response = new RuleResponse();
            response.setId(ruleEntity.getId());
            response.setExpression(ruleEntity.getExpr());
            response.setCondition(ruleEntity.getCond());
            response.setThreshold(ruleEntity.getThreshold());
            response.setTrigger(ruleEntity.getTrig());
            response.setDescription(ruleEntity.getComment());
            response.setCreateTime(ruleEntity.getCreateTime());
            response.setUpdateTime(ruleEntity.getUpdateTime());

            ruleResponseList.add(response);
        }

        return Response.success(ruleResponseList);
    }

    @PostMapping("/add")
    public Response<Object> addAlertRule(@RequestBody AlertRuleAddRequest alertRuleAddRequest) {
        AlertRuleAddDto alertRuleAddDto = new AlertRuleAddDto();
        alertRuleAddDto.setInstanceId(alertRuleAddRequest.getInstanceId());
        alertRuleAddDto.setExpression(alertRuleAddRequest.getExpression());
        alertRuleAddDto.setCondition(alertRuleAddRequest.getCondition());
        alertRuleAddDto.setThreshold(alertRuleAddRequest.getThreshold());
        alertRuleAddDto.setTrigger(alertRuleAddRequest.getTrigger());
        alertRuleAddDto.setDescription(alertRuleAddRequest.getDescription());

        alertRuleService.addAlertRule(alertRuleAddDto);

        return Response.success();
    }

    @PostMapping("/delete")
    public Response<Object> deleteAlertRule(@RequestParam("id") Long alertRuleId) {
        alertRuleService.deleteRule(alertRuleId);

        return Response.success();
    }
}
