package rition.service.panel;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;
import rition.common.data.dao.mapper.AlertMapper;
import rition.common.data.dto.PagingData;
import rition.common.data.entity.AlertEntity;
import rition.common.data.enums.Constants;

@Service
public class AlertHistoryService {
    private final AlertMapper alertMapper;

    public AlertHistoryService(AlertMapper alertMapper) {
        this.alertMapper = alertMapper;
    }

    /**
     * 分页获取报警信息
     *
     * @param instanceId 实例id
     * @param pagingData 分页数据，查询完成后会对此对象进行修改
     * @return 分页数据，含结果，实际上与参数里的pagingData是同一个对象
     */
    public PagingData<AlertEntity> getAlertHistory(String instanceId, PagingData<AlertEntity> pagingData) {
        LambdaQueryWrapper<AlertEntity> query;
        if (instanceId != null) {
            query = new LambdaQueryWrapper<AlertEntity>()
                    .eq(AlertEntity::getInstanceId, instanceId)
                    .eq(AlertEntity::getStatus, Constants.EntityCommonStatus.NORMAL);
        } else {
            query = new LambdaQueryWrapper<AlertEntity>()
                    .eq(AlertEntity::getStatus, Constants.EntityCommonStatus.NORMAL);
        }

        Page<AlertEntity> page = new Page<>(pagingData.getCurrentPage(), pagingData.getPageSize());
        var result = alertMapper.selectPage(page, query);

        pagingData.setData(result.getRecords());
        pagingData.setTotalResult(result.getTotal());
        pagingData.setTotalPage(result.getPages());
        pagingData.setCurrentPage(result.getCurrent());
        pagingData.setPageSize(result.getSize());

        return pagingData;
    }
}
