package rition.service.panel;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import rition.common.data.dao.mapper.MetricRecordMapper;
import rition.common.data.entity.MetricRecordEntity;

import java.time.Instant;
import java.util.List;

@Slf4j
@Service
public class MetricService {

    private final MetricRecordMapper metricRecordMapper;

    public MetricService(MetricRecordMapper metricRecordMapper) {
        this.metricRecordMapper = metricRecordMapper;
    }

    private static final long HOUR = 3600 * 1000;
    private static final long DAY = 24 * 3600 * 1000;
    private static final long MONTH = 30L * 24 * 3600 * 1000;

    /**
     * 按时间范围获取监测数据
     *
     * @param instanceId  实例id
     * @param metricItems 监测指标项
     * @param start       开始时间
     * @param end         结束时间
     * @return 监测指标数据，指标数据为给定的指标平均统计
     */
    public List<MetricRecordEntity> getMetricDataRange(String instanceId,
                                                       List<String> metricItems,
                                                       Instant start, Instant end) {
        // 时间跨度小于6小时：时间粒度为1分钟
        // 时间跨度大于6小时：时间粒度为5分钟
        // 时间跨度大于12小时：时间粒度为10分钟
        // 时间跨度超过15天：时间粒度为小时
        var diff = end.minusMillis(start.toEpochMilli()).toEpochMilli();
        if (diff < HOUR * 6) {
            return metricRecordMapper.getMetricDataGroupByMinute(instanceId, metricItems, start, end);
        } else if (diff < HOUR * 12) {
            return metricRecordMapper.getMetricDataGroupBySomeMinute(5, instanceId, metricItems, start, end);
        } else if (diff < DAY * 15) {
            return metricRecordMapper.getMetricDataGroupBySomeMinute(10, instanceId, metricItems, start, end);
        } else {
            return metricRecordMapper.getMetricDataGroupByHour(instanceId, metricItems, start, end);
        }
    }
}
